#!/usr/bin/env bash

set -euo pipefail

THIS_DIR=$(dirname "$0")

function update() {
    echo "Fetching the latest tag for cern/alma9-base"
    LATEST_TAG=$(curl -s https://registry.hub.docker.com/v2/repositories/cern/alma9-base/tags/ | grep -oP '"name":\s*"\K(\d{8}-\d+)'| sort -V | tail -n 1)
    echo "Latest tag is ${LATEST_TAG}"
    CURRENT_TAG=$(grep -oP "FROM cern/alma9-base:\K[\w.-]+" "${THIS_DIR}/Dockerfile")
    echo "Current tag is ${CURRENT_TAG}"
    export LATEST_TAG
    export CURRENT_TAG
    if [[ "${LATEST_TAG}" == "${CURRENT_TAG}" ]]; then
        echo "Already on latest image; nothing to do."
    else
        echo "Updating Dockerfile to ${LATEST_TAG}"
        sed -i "s|FROM cern/alma9-base:${CURRENT_TAG}|FROM cern/alma9-base:${LATEST_TAG}|g" "$THIS_DIR/Dockerfile";
        git add $THIS_DIR/Dockerfile
        git commit -m "[🛠️ CI] ⏫ Update alma9 container to upstream version $LATEST_TAG"
    fi
}

update
